==> jc-1.4.0.tar.gz: javax/imageio/metadata/IIOMetadataFormatImpl.h <==
// public abstract class javax.imageio.metadata.IIOMetadataFormatImpl

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cb8bb9a4d2601539 javax_imageio_metadata_IIOMetadataFormatImpl

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_metadata_IIOMetadataFormatImpl_H_
#define _JC_javax_imageio_metadata_IIOMetadataFormatImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_refs	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_refs;
typedef struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_nonrefs	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_nonrefs;
typedef struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$refs	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$refs;
typedef struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$nonrefs	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$nonrefs;
typedef struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$object	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$object;

typedef const struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vmethods	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$vmethods;
typedef const struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtable	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtable;
typedef const struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtype	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtype;

// Constructors
extern void _jc_javax_imageio_metadata_IIOMetadataFormatImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$object *);

// Virtual methods structure
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vmethods {
};

// Vtable
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$vmethods	javax_imageio_metadata_IIOMetadataFormatImpl;
};

// Vtype
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtype {
	_jc_type			type;
	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$refs {
    _jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_refs	javax_imageio_metadata_IIOMetadataFormatImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_nonrefs	javax_imageio_metadata_IIOMetadataFormatImpl;
};

// Object instance structure
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$object {
	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtype	*vtype;
	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtype _jc_javax_imageio_metadata_IIOMetadataFormatImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_metadata_IIOMetadataFormatImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_metadata_IIOMetadataFormatImpl$class_object;

#endif	/* _JC_javax_imageio_metadata_IIOMetadataFormatImpl_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/metadata/IIOMetadataFormatImpl.h <==
// public abstract class javax.imageio.metadata.IIOMetadataFormatImpl

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cb8bb9a4d2601539 javax_imageio_metadata_IIOMetadataFormatImpl

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_metadata_IIOMetadataFormatImpl_H_
#define _JC_javax_imageio_metadata_IIOMetadataFormatImpl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_refs	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_refs;
typedef struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_nonrefs	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_nonrefs;
typedef struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$refs	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$refs;
typedef struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$nonrefs	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$nonrefs;
typedef struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$object	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$object;

typedef const struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vmethods	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$vmethods;
typedef const struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtable	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtable;
typedef const struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtype	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtype;

// Constructors
extern void _jc_javax_imageio_metadata_IIOMetadataFormatImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vmethods {
};

// Vtable
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$vmethods	javax_imageio_metadata_IIOMetadataFormatImpl;
};

// Vtype
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtype {
	_jc_type			type;
	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$refs {
    _jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_refs	javax_imageio_metadata_IIOMetadataFormatImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_metadata_IIOMetadataFormatImpl$sub_nonrefs	javax_imageio_metadata_IIOMetadataFormatImpl;
};

// Object instance structure
struct _jc_javax_imageio_metadata_IIOMetadataFormatImpl$object {
	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtype	*vtype;
	_jc_javax_imageio_metadata_IIOMetadataFormatImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_metadata_IIOMetadataFormatImpl$vtype _jc_javax_imageio_metadata_IIOMetadataFormatImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_metadata_IIOMetadataFormatImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_metadata_IIOMetadataFormatImpl$class_object;

#endif	/* _JC_javax_imageio_metadata_IIOMetadataFormatImpl_H_ */
